/*
 * xdata.h:
 * Support library for xdata.
 *
 * Copyright (c) 2001 Chris Lightfoot. All rights reserved.
 *
 * $Id: xdata.h,v 1.3 2001/02/04 03:39:52 chris Exp $
 *
 */

#ifndef __XDATA_H_ /* include guard */
#define __XDATA_H_

#include <gdbm.h>

/* How often data in the database should be purged. */
#ifndef XDATA_PURGE_TIME
#   define XDATA_PURGE_TIME     (7 * 24 * 3600)         /* 1 week. */
#endif

/* Program we use to contact a remote host. */
#ifndef XDATA_RSH
#   define XDATA_RSH            "/usr/bin/rsh"
#endif

typedef enum {success = 0, error} XDATA_ERR;

struct xdata_metadata {
    time_t last_sync, last_purge;
};

typedef struct tag_XDATA {
    char **path, *pdata;
    char *gdbm_name;
    char *type;
    GDBM_FILE gdbm_h;
    XDATA_ERR status;
    char *errmsg;
    struct xdata_metadata metadata;
} *XDATA;


void xdata_set_error(XDATA x, const XDATA_ERR status, char *errmsg);
XDATA xdata_open(const char *path);
void xdata_close(XDATA x);
int xdata_set_type(XDATA x, const char *type, const int writable, const char *create_path);
void xdata_get_metadata(XDATA x);
void xdata_set_metadata(XDATA x);
int xdata_purge(XDATA x);
void *xdata_get(XDATA x, const char *key, size_t *len, time_t *mtime);
int xdata_stat(XDATA x, const char *key, size_t *len, time_t *mtime);
int xdata_exists(XDATA x, const char *key);
int xdata_put(XDATA x, const char *key, const void *val, const size_t len, const time_t mtime, const int replace);
int xdata_remove(XDATA x, const char *key, const time_t mtime);
char *xdata_enum(XDATA x, const int internal, char **key);

#endif /* __XDATA_H_ */
